==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Button/ActionButton/ActionButton.js <==
import '../../node_modules/core-js/modules/es.date.to-string.js';
import '../../node_modules/core-js/modules/es.object.to-string.js';
import '../../node_modules/core-js/modules/es.reflect.construct.js';
import '../../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent.js';
import '../../node_modules/core-js/modules/es.symbol.js';
import '../../node_modules/core-js/modules/es.array.filter.js';
import '../../node_modules/core-js/modules/es.array.for-each.js';
import '../../node_modules/core-js/modules/es.object.define-properties.js';
import '../../node_modules/core-js/modules/es.object.define-property.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../../node_modules/core-js/modules/es.object.keys.js';
import '../../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _mergeJSXProps from '../../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';
import { BaseButton } from '../BaseButton.js';
import { getStyles } from './ActionButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var ActionButton = function (_BaseComponent) {
  _inherits(ActionButton, _BaseComponent);

  var _super = _createSuper(ActionButton);

  function ActionButton() {
    _classCallCheck(this, ActionButton);

    return _super.apply(this, arguments);
  }

  _createClass(ActionButton, [{
    key: "render",
    value: function render() {
      var h = arguments[0];

      var props = _objectSpread(_objectSpread({}, this.$props), {}, {
        variantClassName: 'ms-Button--action ms-Button--command',
        styles: this.internalStyles
      });

      return h(BaseButton, _mergeJSXProps([{}, {
        props: props,
        attrs: this.$attrs,
        on: this.$listeners,
        scopedSlots: this.$scopedSlots
      }]));
    }
  }, {
    key: "internalStyles",
    get: function get() {
      var theme = this.theme,
          styles = this.styles;
      return getStyles(theme, styles);
    }
  }]);

  return ActionButton;
}(BaseComponent);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], ActionButton.prototype, "href", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], ActionButton.prototype, "disabled", void 0);

__decorate([Prop({
  type: Object,
  "default": null
}), __metadata("design:type", Object)], ActionButton.prototype, "iconProps", void 0);

ActionButton = __decorate([Component], ActionButton);

export { ActionButton };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Button/ActionButton/ActionButton.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { BaseButton } from '../BaseButton.js';
import { getStyles } from './ActionButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var ActionButton = function (_BaseComponent) {
  _inherits(ActionButton, _BaseComponent);

  var _super = _createSuper(ActionButton);

  function ActionButton() {
    _classCallCheck(this, ActionButton);

    return _super.apply(this, arguments);
  }

  _createClass(ActionButton, [{
    key: "render",
    value: function render() {
      var h = arguments[0];

      var props = _objectSpread(_objectSpread({}, this.$props), {}, {
        variantClassName: 'ms-Button--action ms-Button--command',
        styles: this.internalStyles
      });

      return h(BaseButton, _mergeJSXProps([{}, {
        props: props,
        attrs: this.$attrs,
        on: this.$listeners,
        scopedSlots: this.$scopedSlots
      }]));
    }
  }, {
    key: "internalStyles",
    get: function get() {
      var theme = this.theme,
          styles = this.styles;
      return getStyles(theme, styles);
    }
  }]);

  return ActionButton;
}(BaseComponent);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], ActionButton.prototype, "href", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ActionButton.prototype, "disabled", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], ActionButton.prototype, "iconProps", void 0);

ActionButton = __decorate([Component], ActionButton);

export { ActionButton };
